@@ -144,7 +144,7 @@ def push_environment(
         hud_console.warning("A HUD API key is required to push environments.")
         hud_console.info("\nTo get started:")
         hud_console.info("1. Get your API key at: https://hud.so/settings")
-        hud_console.command_example("export HUD_API_KEY=your-key-here", "Set your API key")
+        hud_console.info("Set it in your environment or run: hud set HUD_API_KEY=your-key-here")
         hud_console.command_example("hud push", "Try again")
         hud_console.info("")
         raise typer.Exit(1)
@@ -332,6 +332,7 @@ def push_environment(
         "source": local_image,
         "pushedAt": datetime.now(UTC).isoformat().replace("+00:00", "Z"),
         "registry": pushed_digest.split("/")[0] if "/" in pushed_digest else "docker.io",
+        "image_with_tag": image,
     }
 
     # Save updated lock file
@@ -413,6 +414,7 @@ def push_environment(
             hud_console.error("Authentication failed")
             hud_console.info("Check your HUD_API_KEY is valid")
             hud_console.info("Get a new key at: https://hud.so/settings")
+            hud_console.info("Set it in your environment or run: hud set HUD_API_KEY=your-key-here")
         elif response.status_code == 403:
             hud_console.error("Permission denied")
             hud_console.info("You may not have access to push to this namespace")
